# Copyright 2014 - 2019, 2021 Paul Hänsch
#
# This file is part of Confetti.
# 
# Confetti is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# 
# Confetti is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
# 
# You should have received a copy of the GNU Affero General Public License
# along with Confetti.  If not, see <http://www.gnu.org/licenses/>. 

list_categories() {
  grep -vxE '^[ 	]*$' "${_DATA}/mappings/categories"
}

w_filter_item() {
n=$3
cat <<EOF
  [fieldset .item
    [legend $(l10n filter_item):]

    $(for field in any name street zip TEL BDAY CATEGORIES course; do
      printf '[input id="%s%i" type="radio" name="filter_type%i" value="%s" %s][label for="%s%i" %s ]' \
              "$field" "$n" "$n" "$field" "$([ "$1" = "$field" ] && printf checked )" \
              "$field" "$n" "$(l10n filter_$field)"
    done)
    [input type="text" name="filter_text$n" value="$([ "$1" = CATEGORIES -o "$1" = course ] || HTML "$2")" placeholder="$(l10n filter_placeholder)"]
    [fieldset .categories
      $(list_categories | while read cat; do
          printf '[label [checkbox "filter_cat%i" "|%s" %s] %s ] ' \
                 "$n" "$(HTML "$cat")" \
                 "$(printf %s "$cat" |grep -qxEe "$2" && printf checked )" \
                 "$(HTML "$cat")"
      done)
      [a href="/categories/" $(l10n edit_categories)]
    ]
    [fieldset .courses
      $(for course in "$_DATA/ical"/*.ics; do
        printf '[label [checkbox "filter_course%i" "|%s" %s] %s ] ' \
               "$n" "$(HTML "${course##*/}")" \
               "$(printf %s "${course##*/}" |grep -qxEe "$2" && printf checked )" \
               "$(pdi_value "$(pdi_load "$course")" SUMMARY |HTML)"
      done)
    ]
  ]
EOF
}

w_filter_diag(){
  cat <<EOF
  [form .filter action="/cards/filter_card.sh" method="POST"
    [h1 $(l10n filter_label)]
    [input type="hidden" name="page" value="cards"]
  
    $(n=0; filter="${filter}^"
      while [ "${filter#^}" ]; do
        fil="${filter%%^*}" filter="${filter#*^}"
        w_filter_item "${fil%%:*}" "${fil#*:}" $n
        n=$((n + 1))
      done
      [ "$n" -eq 0 -o "$(GET newfilter)" ] && w_filter_item any '' $n
    )
    [button type="submit" name="choice" value="new_filter" $(l10n filter_more)]
    [fieldset class="order"
      [legend $(l10n filter_order):]
      [label [radio "order" "firstname" $( [ "$order" = firstname ] && printf checked )] $(l10n filter_firstname)]
      [label [radio "order" "lastname"  $( [ "$order" = lastname  ] && printf checked )] $(l10n filter_lastname)]
      [label [radio "order" "bdate"     $( [ "$order" = bdate     ] && printf checked )] $(l10n filter_bdate)]
    ]
    [button type="submit" name="choice" value="filter" $(l10n filter_apply)]
    [button type="submit" name="choice" value="del_filter" $(l10n filter_cancel)]
    [button type="submit" name="choice" value="export_csv" $(l10n export_csv)]
  ]
EOF
}

# listcards |grep ${edit:+-v} "$edit" \
# | while read card; do
#   "${_EXEC}"/cgilite/html-sh.sed <<-ENDCARD
# 	[div #${card} .card
# 	  $(view_card "$card")[!--
# 	  --][div .control
# 	    [a "?action=edit_card&card=${card}" .item $(l10n edit)]
# 	    [a "?action=export_vcard&card=${card}".item $(l10n vcf_export)]
# 	    ${profile_medical:+[a "?action=new_prescription&client=${card}" .item $(l10n new_prescription)]}
# 	]]
# 	ENDCARD
# done

#!/bin/sh

card_item(){
  local card="$1"
  local item cnt c
  shift 1

  for item in $@; do
    cnt="$(pdi_count "$card" "$item")"

    case $item in
      FN) printf '[h2 .item .FN . %s]' "$(pdi_value "$card" FN |unescape |HTML)"
        ;;
      GENDER) printf '[span .item .GENDER . %s]' "$(pdi_value "$card" GENDER |l10n)"
        ;;
      NICKNAME) seq 1 $cnt |while read c; do
          printf '[span .item .NICKNAME . aka. "%s"]' \
                 "$(pdi_value "$card" NICKNAME $c |unescape |HTML)"
        done
        ;;
      X-ZACK-JOINDATE|X-ZACK-LEAVEDATE) if [ $cnt -gt 0 ]; then
          printf '[span .item .%s [b %s:] %s]' \
                 "$item" "$(l10n "${item}_short")" \
                 "$(pdi_value "$card" "$item" |HTML)"
        fi
        ;;
      BDAY)
       [ $cnt -gt 0 ] && printf '[span .item .BDAY [b *:] %s]' \
                                "$(pdi_value "$card" BDAY |grep -xE '[0-9-]+')"
        ;;
      SOUND)
        [ $cnt -gt 0 ] && printf '[audio .item .SOUND controls="controls"
                                    [source type="audio/ogg" src="data:audio/ogg;base64,%s"]
                                  ]' \
                                  "$(pdi_value "$card" SOUND |grep -xE '[a-zA-Z0-9/+=]+')"
        ;;
      PHOTO|LOGO)
        [ $cnt -gt 0 ] && printf '[img .item .%s src="data:image/%s;base64,%s"]' "$item" \
                                 "$(pdi_attrib "$card" "$item" |sed -E 's;^(.*;)?TYPE="?(.+)"?(;.*)?$;\2;')" \
                                 "$(pdi_value "$card" "$item" |grep -xE '[a-zA-Z0-9/+=]+')"
        ;;
      EMAIL) 
        [ $cnt -gt 0 ] && printf '[h3 %s]' "$(l10n EMAIL)"
        seq 1 $cnt |while read c; do
          printf '[a .item .EMAIL href="mailto:%s" . %s]' \
                 "$(pdi_value "$card" EMAIL $c |unescape |HTML)" \
                 "$(pdi_value "$card" EMAIL $c |unescape |HTML)"
        done
        ;;
      TEL)
        [ $cnt -gt 0 ] && printf '[h3 %s]' "$(l10n TEL)"
        seq 1 $cnt |while read c; do
          teltype="$(pdi_attrib "$card" TEL $c TYPE)"
          [ "$teltype" ] \
          && printf '[span .item .TEL [span .type . %s:] %s]' \
                    "$(l10n "TYPE=$teltype" |HTML)" \
                    "$(pdi_value "$card" TEL $c |unescape |HTML)" \
          || printf '[span .item .TEL . %s]' \
                    "$(pdi_value "$card" TEL $c |unescape |HTML)"
        done
        ;;
      *)[ $cnt -gt 0 ] && printf '[h3 %s]' "$(l10n "$item")"
        seq 1 $cnt |while read c; do
          printf '[span .item .%s . %s]' "$item" \
                 "$(pdi_value "$card" "$item" $c |unescape |HTML)"
        done
        ;;
    esac
  done
}

edit_item(){
  local card="$1"
  local item cnt c
  shift 1

  for item in $@; do
    cnt="$(pdi_count "$card" "$item")"
    [ $cnt -lt 1 ] && cnt=1

    case $item in
      N)N="$(pdi_value "$card" N)"
        if [ "$N" ]; then
          IFS=\; read n1 n2 n3 n4 n5 <<-EOF
		$N
		EOF
        else
	  N="$(pdi_value "$card" FN |unescape)"
          n1="${N##* }"
          n2="${N%$n1}"
        fi
        printf '
        [h3 %s]
        [input .item .N name="4N" placeholder="%s" value="%s"]
        [input .item .N name="2N" placeholder="%s" value="%s"]
        [input .item .N name="1N" placeholder="%s" value="%s"]
        [input .item .N name="5N" placeholder="%s" value="%s"]
        ' "$(l10n "$item")" \
        "$(l10n n_pre)"   "$(HTML "$n4")" \
        "$(l10n n_first)" "$(HTML "${n2}$([ "$n2" -a "$n3" ] && printf ' ')${n3}")" \
        "$(l10n n_last)"  "$(HTML "$n1")" \
        "$(l10n n_post)"  "$(HTML "$n5")"
        ;;
      GENDER)
        gender="$(pdi_value "$card" GENDER)"
        printf '
        [select .item .GENDER name="GENDER"
          [option value="" disabled="disabled" %s %s]
          [option value="female" %s %s]
          [option value="male"   %s %s]
          [option value="other"  %s %s]
          [option value="none"   %s %s]
        ]\n' \
        "$([ "$gender" = ''       ] && printf 'selected="selected"')" "$(l10n GENDER)" \
        "$([ "$gender" = 'female' ] && printf 'selected="selected"')" "$(l10n gender_female)" \
        "$([ "$gender" = 'male'   ] && printf 'selected="selected"')" "$(l10n gender_male)" \
        "$([ "$gender" = 'other'  ] && printf 'selected="selected"')" "$(l10n gender_other)" \
        "$([ "$gender" = 'none'   ] && printf 'selected="selected"')" "$(l10n gender_none)"
        ;;
      BDAY|X-ZACK-JOINDATE|X-ZACK-LEAVEDATE)
        printf '[h3 %s]
        [input .item .%s name="%s" value="%s" placeholder="YYYY-MM-DD"]' \
        "$(l10n "$item")" "$item" "$item" "$(pdi_value "$card" "$item" |grep -xE '[0-9-]+')"
        ;;
      ADR|NOTE)
        printf '[h3 %s]' "$(l10n "$item")"
        seq 1 $cnt |while read c; do
          printf '[checkbox "%s_delete_%i" "true" .delete #%s_delete_%i][label for="%s_delete_%i" %s]' \
            "$item" $c "$item" $c "$item" $c "$(l10n delete)"
          printf '<textarea class="item %s" name="%s">%s</textarea>' \
            "$item" "$item" "$(pdi_value "$card" "$item" $c |unescape |HTML)"
        done
        printf '[button type="submit" name="action" value="addfield %s" %s ]' "$item" "$(l10n edit_addfield)"
        ;;
      TEL) printf '[h3 %s]' "$(l10n "$item")"
        seq 1 $cnt |while read c; do
          printf '[checkbox "%s_delete_%i" "true" .delete #%s_delete_%i][label for="%s_delete_%i" %s]' \
            "$item" $c "$item" $c "$item" $c "$(l10n delete)"
          teltype="$(pdi_attrib "$card" TEL $c TYPE)"
          printf '[select .item .teltype name="teltype"
                    [option value="" disabled="disabled" %s %s]
                    [option value="HOME" %s %s]
                    [option value="WORK" %s %s]
                    [option value="CELL" %s %s]
                    [option value="FAX"  %s %s]
                  ]\n' \
                  "$([ "$teltype" = ''     ] && printf 'selected="selected"')" "$(l10n teltype)" \
                  "$([ "$teltype" = 'HOME' ] && printf 'selected="selected"')" "$(l10n TYPE=HOME)" \
                  "$([ "$teltype" = 'WORK' ] && printf 'selected="selected"')" "$(l10n TYPE=WORK)" \
                  "$([ "$teltype" = 'CELL' ] && printf 'selected="selected"')" "$(l10n TYPE=CELL)" \
                  "$([ "$teltype" = 'FAX'  ] && printf 'selected="selected"')" "$(l10n TYPE=FAX)"

          printf '[input .item .%s name="%s" value="%s" placeholder="%s"]' \
            "$item" "$item" "$(pdi_value "$card" "$item" $c |unescape |HTML)" "$(l10n "$item")"
        done
        printf '[button type="submit" name="action" value="addfield %s" %s ]' "$item" "$(l10n edit_addfield)"
        ;;
      *)printf '[h3 %s]' "$(l10n "$item")"
        seq 1 $cnt |while read c; do
          printf '[checkbox "%s_delete_%i" "true" .delete #%s_delete_%i][label for="%s_delete_%i" %s]' \
            "$item" $c "$item" $c "$item" $c "$(l10n delete)"
          printf '[input .item .%s name="%s" value="%s" placeholder="%s"]' \
            "$item" "$item" "$(pdi_value "$card" "$item" $c |unescape |HTML)" "$(l10n "$item")"
        done
        printf '[button type="submit" name="action" value="addfield %s" %s ]' "$item" "$(l10n edit_addfield)"
        ;;
    esac
  done
}
